#!/bin/sh

usage() {
    echo "Usage: $0 [-a \$path] [-m]"
    exit 1
}

kill_process() {
    echo `date`
    if [ -z == "$1" ]; then
        echo "error. input process argument. check script file."
        exit 1
    fi

    SHELL_NAME="${0##*/}"
    PS_TYPE="normal"
    PS_PATH=`which ps`
    REAL_PATH=`readlink $PS_PATH`
    if [ "busybox" == "$REAL_PATH" ]; then
        PS_TYPE="busybox"
    fi

    if [ "normal" == "$PS_TYPE" ]; then
        AGENT=`ps -ef | grep -v grep | grep -v $SHELL_NAME | awk '{print $2,$8}' |grep $1`
    else
        AGENT=`ps -ef | grep -v grep | grep -v $SHELL_NAME | awk '{print $1,$4}' |grep $1`
        if [ -z "$AGENT" ]
        then
            echo "$1 process is not running."
        else
            echo "kill process info : $AGENT"
            PID=$(echo $AGENT | cut -f1 -d ' ')
            echo "kill pid $PID"
            kill $PID
            sleep 3
            kill -9 $PID 2>/dev/null
            pkill -9 -x "/opt/rsupport/rvbox/agent/latest/$1"
        fi
    fi
}

make_sysdir() {
    mkdir -p /etc/rsupport/rvbox/agent
    mkdir -p /var/spool/cron/crontabs

    mkdir -p /var/lock

    mkdir -p /mnt/emmc1/log/rsupport
    mkdir -p /var/log
    cd /var/log

    if [ ! -L /var/log/rsupport ]; then
        ln -s /mnt/emmc1/log/rsupport rsupport
    fi
}

make_conf() {
    if [ -e /etc/rsupport/rvbox/agent/agent.conf ]; then 
       mv /etc/rsupport/rvbox/agent/agent.conf /etc/rsupport/rvbox/agent/agent.confsA4h10Q5
    fi 
    mv /opt/rsupport/rvbox/agent/1.0.0.01/agent.conf /etc/rsupport/rvbox/agent

    if [ -e /etc/rsupport/rvbox/agent/control.conf ]; then 
       mv /etc/rsupport/rvbox/agent/control.conf /etc/rsupport/rvbox/agent/control.confsA4h10Q5
    fi 
    mv /opt/rsupport/rvbox/agent/1.0.0.01/control.conf /etc/rsupport/rvbox/agent


    if [ -e /etc/rsupport/rvbox/agent/starter.conf ]; then 
       mv /etc/rsupport/rvbox/agent/starter.conf /etc/rsupport/rvbox/agent/starter.confsA4h10Q5
    fi 
    mv /opt/rsupport/rvbox/agent/1.0.0.01/starter.conf /etc/rsupport/rvbox/agent

    if [ -e /etc/init.d/app.sh ]; then 
       mv /etc/init.d/app.sh /etc/init.d/app.shsA4h10Q5
    fi 
    mv /opt/rsupport/rvbox/agent/1.0.0.01/app.sh /etc/init.d/app.sh
    chmod 755 /etc/init.d/app.sh

}
make_etc() {
    mkdir -p /opt/rsupport/rvbox/var/tmp
    if [ -e /opt/rsupport/rvbox/var/tmp/liveview_failed.jpg ]; then 
       mv /opt/rsupport/rvbox/var/tmp/liveview_failed.jpg /opt/rsupport/rvbox/var/tmp/liveview_failed.jpgsA4h10Q5
    fi 
    mv /opt/rsupport/rvbox/agent/1.0.0.01/liveview_failed.jpg /opt/rsupport/rvbox/var/tmp

}

# START
ARCHIVE_PATH=""
INSTALL_TYPE=""

while getopts "a:mh" option
do
    case $option in
    a)
        INSTALL_TYPE="auto"
        ARCHIVE_PATH="$OPTARG"
        ;;
    m)
        INSTALL_TYPE="manual"
        ARCHIVE_PATH=`pwd`
        ;;
    h) usage ;;
    ?) usage ;;
    esac
done

if [ -z $INSTALL_TYPE ] || [ -z $ARCHIVE_PATH ]; then
    echo "no args..."
    usage
fi

if [ ! -d $ARCHIVE_PATH ]; then
    echo "invalid path.."
    exit 1
fi

CHECK_FILE_LIST="rv_capture rv_agent lib/libcrypto.so lib/libpaho-mqtt3c.so.1 lib/libopus.so.0 lib/librsnet.so lib/libpaho-mqtt3cs.so lib/libcpr.so lib/libvendor_media.so lib/libcurl.so lib/libpaho-mqttpp3.so.1 lib/libjpeg.so.9 lib/libssl.so.1.0.0 lib/libpaho-mqtt3as.so.1.3.11 lib/libpaho-mqtt3a.so lib/libvideo_system.so lib/libjpeg.so.9.5.0 lib/libpaho-mqttpp3.so.1.2.0 lib/libpaho-mqttpp3.so lib/libpaho-mqtt3as.so lib/libproperty.so lib/libpaho-mqtt3cs.so.1.3.11 lib/libpaho-mqtt3as.so.1 lib/libtinyxml2.so.7 lib/libpaho-mqtt3a.so.1 lib/libopus.so.0.9.0 lib/librspxauth.so lib/libtinyxml2.so.7.0.1 lib/libtinyxml2.so lib/libhdal.so lib/libcrypto.so.1.0.0 lib/libjpeg.so lib/libopus.so lib/libpaho-mqtt3c.so.1.3.11 lib/libpaho-mqtt3cs.so.1 lib/libssl.so lib/libpaho-mqtt3a.so.1.3.11 lib/libxenc.so lib/liblispace.so lib/libpaho-mqtt3c.so djpeg rv_updater rv_control rv_starter initworker "

UPDATE_ROLLBACK="false"
VERSION=1.0.0.01
INSTALL_DIR=/opt/rsupport/rvbox/agent/1.0.0.01
PACKAGE_FILE_NAME=RemoteViewBox2-agent-1.0.0.01.tar.gz
cd $ARCHIVE_PATH
echo "1. Installing RemoteViewBOX2-agent at /opt/rsupport/rvbox/agent/1.0.0.01"

if [ -d /opt/rsupport/rvbox/agent/1.0.0.01 ]; then  # if pacakage version is same
    mv /opt/rsupport/rvbox/agent/1.0.0.01 /opt/rsupport/rvbox/agent/sA4h10Q5
fi
mkdir -p /opt/rsupport/rvbox/agent/1.0.0.01

echo "2. Extract compressed files"
if [ "auto" == "$INSTALL_TYPE" ]
then
    if [ -e .information2-agent.gz ]; then
        rm .information2-agent.gz
    fi

    if [ -e RemoteViewBox2-agent-1.0.0.01.tar.gz ]; then
        rm RemoteViewBox2-agent-1.0.0.01.tar.gz
    fi
    cp -a . /opt/rsupport/rvbox/agent/1.0.0.01
else
    tar zxf $ARCHIVE_PATH/RemoteViewBox2-agent-1.0.0.01.tar.gz -C /opt/rsupport/rvbox/agent/1.0.0.01
    gzip -d -f .information2-agent.gz
    cp .information2-agent /opt/rsupport/rvbox/agent/1.0.0.01
    gzip .information2-agent
fi

echo "3. make sysdir"
make_sysdir

echo "4. make conf files"
make_conf

echo "5. make etc files"
make_etc

echo "6. Stop cron schedule"
crontab -r
AGENT_WATCH_PID=`ps -ef | grep -v grep | grep "for i in 1 2 3; do /opt/rsupport/rvbox/agent/latest/watchdog.sh agent && sleep 15; done" | awk '{print $1}'`
if [ -z "$AGENT_WATCH_PID" ]
then
   echo "agent watchdog is not running"
else
   echo "kill agent watchdog"
   kill -9 $AGENT_WATCH_PID
fi

echo "7. Kill agent proess"
kill_process rv_agent

echo "8. Check install files"
for CHECK_FILE in $CHECK_FILE_LIST
do
    if [ -e $INSTALL_DIR/$CHECK_FILE ] && [ -s $INSTALL_DIR/$CHECK_FILE ]; then 
        echo "ok...$CHECK_FILE"
     else
         echo "err...$CHECK_FILE"
         UPDATE_ROLLBACK="true"
    fi
done;

if [ "false" == "$UPDATE_ROLLBACK" ]
then
    echo "    8.1. Install Success. "
    if [ -d /opt/rsupport/rvbox/agent/sA4h10Q5 ]; then  # if pacakage version is same
        rm -rf /opt/rsupport/rvbox/agent/sA4h10Q5
    fi

    # delete backup conf files.(agent.conf, control.conf, starter.conf, app.sh)
    if [ -e /etc/rsupport/rvbox/agent/agent.confsA4h10Q5 ]; then 
       rm /etc/rsupport/rvbox/agent/agent.confsA4h10Q5
    fi 
    if [ -e /etc/rsupport/rvbox/agent/control.confsA4h10Q5 ]; then 
       rm /etc/rsupport/rvbox/agent/control.confsA4h10Q5
    fi 
    if [ -e /etc/rsupport/rvbox/agent/starter.confsA4h10Q5 ]; then 
       rm /etc/rsupport/rvbox/agent/starter.confsA4h10Q5
    fi 
    if [ -e /etc/init.d/app.shsA4h10Q5 ]; then 
       rm /etc/init.d/app.shsA4h10Q5
    fi 
    # delete etc files.(liveview_failed.jpg)
    if [ -e /opt/rsupport/rvbox/var/tmp/liveview_failed.jpgsA4h10Q5 ]; then 
       rm /opt/rsupport/rvbox/var/tmp/liveview_failed.jpgsA4h10Q5
    fi 

    if [ -L /opt/rsupport/rvbox/agent/latest ]; then
        CURRENT_VERSION_PATH=`readlink /opt/rsupport/rvbox/agent/latest`
        rm /opt/rsupport/rvbox/agent/latest

        if [ "$CURRENT_VERSION_PATH" == "/opt/rsupport/rvbox/agent/1.0.0.01" ]; then   # if pacakage version is same
           echo "pacakage version is same"
        elif [ -d $CURRENT_VERSION_PATH ]; then  # if the package version is different, delete old version
           echo "delete $CURRENT_VERSION_PATH"
           rm -rf $CURRENT_VERSION_PATH
        fi
    fi
    echo "1.0.0.0101" > /opt/rsupport/rvbox/version
    ln -sf /opt/rsupport/rvbox/agent/1.0.0.01 /opt/rsupport/rvbox/agent/latest
else
    echo "    8.1. Install Fail.  rollback."
    rm -rf /opt/rsupport/rvbox/agent/1.0.0.01
    if [ -d /opt/rsupport/rvbox/agent/sA4h10Q5 ]; then
        mv /opt/rsupport/rvbox/agent/sA4h10Q5 /opt/rsupport/rvbox/agent/1.0.0.01
    fi
    # rollback conf files.(agent.conf, control.conf, app.sh)
    if [ -e /etc/rsupport/rvbox/agent/agent.confsA4h10Q5 ]; then 
       mv /etc/rsupport/rvbox/agent/agent.confsA4h10Q5 /etc/rsupport/rvbox/agent/agent.conf
    fi 

    if [ -e /etc/rsupport/rvbox/agent/control.confsA4h10Q5 ]; then 
       mv /etc/rsupport/rvbox/agent/control.confsA4h10Q5 /etc/rsupport/rvbox/agent/control.conf
    fi 

    if [ -e /etc/rsupport/rvbox/agent/starter.confsA4h10Q5 ]; then 
       mv /etc/rsupport/rvbox/agent/starter.confsA4h10Q5 /etc/rsupport/rvbox/agent/starter.conf
    fi 

    if [ -e /etc/init.d/app.shsA4h10Q5 ]; then 
       mv /etc/init.d/app.shsA4h10Q5 /etc/init.d/app.sh
    fi 

    # rollback etc files.(liveview_failed.jpg)
    if [ -e /opt/rsupport/rvbox/var/tmp/liveview_failed.jpgsA4h10Q5 ]; then 
       mv /opt/rsupport/rvbox/var/tmp/liveview_failed.jpgsA4h10Q5 /opt/rsupport/rvbox/var/tmp/liveview_failed.jpg
    fi 

fi

echo "9. Register cron schedule"
echo "* * * * * for i in 1 2 3; do /opt/rsupport/rvbox/agent/latest/watchdog.sh agent && sleep 15; done" > /var/spool/cron/crontabs/root
echo "* * * * * for i in 1 2 3; do /opt/rsupport/rvbox/web/latest/watchdog.sh web && sleep 15; done" >> /var/spool/cron/crontabs/root

rm /opt/rsupport/rvbox/agent/latest/install-agent.sh

echo "10. Synchronize Storage"
sync

echo "11. Start Watchdog"
/opt/rsupport/rvbox/agent/latest/watchdog.sh agent -d

