#!/bin/sh

usage() {
    echo "Usage: $0 [-a \$path] [-m]"
    exit 1
}

kill_process() {
    echo `date`
    if [ -z == "$1" ]; then
        echo "error. input process argument. check script file."
        exit 1
    fi

    SHELL_NAME="${0##*/}"
    PS_TYPE="normal"
    PS_PATH=`which ps`
    REAL_PATH=`readlink $PS_PATH`
    if [ "busybox" == "$REAL_PATH" ]; then
        PS_TYPE="busybox"
    fi

    if [ "normal" == "$PS_TYPE" ]; then
        AGENT=`ps -ef | grep -v grep | grep -v $SHELL_NAME | awk '{print $2,$8}' |grep $1`
    else
        AGENT=`ps -ef | grep -v grep | grep -v $SHELL_NAME | awk '{print $1,$4}' |grep $1`
        if [ -z "$AGENT" ]
        then
            echo "$1 process is not running."
        else
            echo "kill process info : $AGENT"
            PID=$(echo $AGENT | cut -f1 -d ' ')
            echo "kill pid $PID"
            kill -9 $PID
        fi
    fi
}

make_sysdir() {
    mkdir -p /etc/rsupport/rvbox/web
    mkdir -p /var/spool/cron/crontabs

    mkdir -p /var/tmp
    mkdir -p /var/lock

    mkdir -p /mnt/emmc1/log/rsupport
    mkdir -p /var/log
    cd /var/log

    if [ ! -L /var/log/rsupport ]; then
        ln -s /mnt/emmc1/log/rsupport rsupport
    fi

    # for lighttpd.conf
    mkdir -p /tmp
    # for wpa_supplicant.conf (wifi)
    mkdir -p /etc/wpa_supplicant
}

make_conf() {
    # "web.conf" is NOT overwrite  
    if [ -e /etc/rsupport/rvbox/web/web.conf ]; then 
       rm /opt/rsupport/rvbox/web/1.0.0.01/web.conf
    else
       mv /opt/rsupport/rvbox/web/1.0.0.01/web.conf /etc/rsupport/rvbox/web
    fi 

    if [ -e /etc/rsupport/rvbox/web/lighttpd.conf ]; then 
       mv /etc/rsupport/rvbox/web/lighttpd.conf /etc/rsupport/rvbox/web/lighttpd.conf1n3OVRAW
    fi 
    mv /opt/rsupport/rvbox/web/1.0.0.01/lighttpd.conf /etc/rsupport/rvbox/web/lighttpd.conf

    if [ -e /etc/init.d/network.sh ]; then 
       mv /etc/init.d/network.sh /etc/init.d/network.sh1n3OVRAW
    fi 
    mv /opt/rsupport/rvbox/web/1.0.0.01/network.sh /etc/init.d/network.sh
    chmod 755 /etc/init.d/network.sh

    if [ -e /etc/init.d/ip_renewal.sh ]; then 
       mv /etc/init.d/ip_renewal.sh /etc/init.d/ip_renewal.sh1n3OVRAW
    fi 
    mv /opt/rsupport/rvbox/web/1.0.0.01/ip_renewal.sh /etc/init.d/ip_renewal.sh
    chmod 755 /etc/init.d/ip_renewal.sh

    if [ -e /etc/init.d/app.sh ]; then 
       mv /etc/init.d/app.sh /etc/init.d/app.sh1n3OVRAW
    fi 
    mv /opt/rsupport/rvbox/web/1.0.0.01/app.sh /etc/init.d/app.sh
    chmod 755 /etc/init.d/app.sh

}

# START
ARCHIVE_PATH=""
INSTALL_TYPE=""

while getopts "a:mh" option
do
    case $option in
    a)
        INSTALL_TYPE="auto"
        ARCHIVE_PATH="$OPTARG"
        ;;
    m)
        INSTALL_TYPE="manual"
        ARCHIVE_PATH=`pwd`
        ;;
    h) usage ;;
    ?) usage ;;
    esac
done

if [ -z $INSTALL_TYPE ] || [ -z $ARCHIVE_PATH ]; then
    echo "no args..."
    usage
fi

if [ ! -d $ARCHIVE_PATH ]; then
    echo "invalid path.."
    exit 1
fi

CHECK_FILE_LIST="cgi-bin/network.fcgi cgi-bin/msg.fcgi cgi-bin/device.fcgi cgi-bin/hello.fcgi cgi-bin/log.fcgi cgi-bin/account.fcgi cgi-bin/check_server.fcgi lib/mod_openssl.so lib/libcrypto.so lib/mod_rrdtool.so lib/mod_alias.so lib/mod_ajp13.so lib/libfcgi++.so lib/mod_secdownload.so lib/libpcrecpp.so.0 lib/mod_userdir.so lib/mod_fastcgi.so lib/libpcre.so.1 lib/libpcrecpp.so lib/mod_flv_streaming.so lib/mod_proxy.so lib/libcpr.so lib/libvendor_media.so lib/libcurl.so lib/libssl.so.1.0.0 lib/mod_setenv.so lib/libpcre.so lib/libvideo_system.so lib/libpcre.so.1.2.13 lib/mod_access.so lib/mod_indexfile.so lib/mod_auth.so lib/libpcreposix.so lib/mod_extforward.so lib/mod_redirect.so lib/mod_wstunnel.so lib/libproperty.so lib/libtinyxml2.so.7 lib/libfcgi++.so.0 lib/librspxauth.so lib/libtinyxml2.so.7.0.1 lib/libtinyxml2.so lib/libhdal.so lib/libfcgi++.so.0.0.0 lib/mod_vhostdb.so lib/libcrypto.so.1.0.0 lib/mod_sockproxy.so lib/mod_staticfile.so lib/mod_simple_vhost.so lib/mod_authn_file.so lib/mod_cgi.so lib/mod_webdav.so lib/mod_status.so lib/libpcreposix.so.0 lib/mod_expire.so lib/mod_scgi.so lib/libpcreposix.so.0.0.7 lib/libfcgi.so.0 lib/libpcrecpp.so.0.0.2 lib/mod_usertrack.so lib/mod_rewrite.so lib/libssl.so lib/libfcgi.so lib/mod_evasive.so lib/libfcgi.so.0.0.0 lib/mod_mbedtls.so lib/libxenc.so lib/mod_dirlisting.so lib/mod_accesslog.so lib/liblispace.so lib/mod_uploadprogress.so lib/mod_evhost.so lib/mod_deflate.so lib/mod_ssi.so certs/crt.pem certs/priv.pem certs/lighttpd_crt.pem lighttpd www/favicon.ico www/static/css/c818a074f8319fd195dd.css www/static/js/1e1869f7b8f3b732d1be.js www/static/js/c818a074f8319fd195dd.js www/static/js/625eb40637441175b318.js www/static/js/b94bc009c612cc8bca01.js www/static/js/32ad53bec041e2f527ab.js.LICENSE.txt www/static/js/625eb40637441175b318.js.LICENSE.txt www/static/js/c96a0ddd80954272e212.js www/static/js/5a427d2150ed8a2410b1.js www/static/js/5f2c411061daaeb693ba.js www/static/js/5e6d2f46818bd15ae6c9.js www/static/js/c89791cc2306391118aa.js www/static/js/fb42819f9ab4c7ad6c9b.js www/static/js/ebf6383944eeec45bc8a.js www/static/js/c818a074f8319fd195dd.js.LICENSE.txt www/static/js/1cc38d8f023ff5c8bb24.js www/static/js/c85f2db311d1eb66a37c.js www/static/js/7e5023635e83a3997611.js www/static/js/32ad53bec041e2f527ab.js www/static/img/rvbox-firmware_ja.png www/static/img/rvbox-firmware.png www/static/img/rvbox-firmware_zh-CN.png www/static/img/rvbox-firmware_en.png www/static/img/rvbox-logo.png www/index.html "

UPDATE_ROLLBACK="false"
VERSION=1.0.0.01
INSTALL_DIR=/opt/rsupport/rvbox/web/1.0.0.01
PACKAGE_FILE_NAME=RemoteViewBox2-web-1.0.0.01.tar.gz
cd $ARCHIVE_PATH
echo "1. Installing RemoteViewBOX2-web at /opt/rsupport/rvbox/web/1.0.0.01"

if [ -d /opt/rsupport/rvbox/web/1.0.0.01 ]; then  # if pacakage version is same
    mv /opt/rsupport/rvbox/web/1.0.0.01 /opt/rsupport/rvbox/web/1n3OVRAW
fi
mkdir -p /opt/rsupport/rvbox/web/1.0.0.01

echo "2. Extract compressed files"
if [ "auto" == "$INSTALL_TYPE" ]
then
    if [ -e .information2-web.gz ]; then
        rm .information2-web.gz
    fi

    if [ -e RemoteViewBox2-web-1.0.0.01.tar.gz ]; then
        rm RemoteViewBox2-web-1.0.0.01.tar.gz
    fi
    cp -a . /opt/rsupport/rvbox/web/1.0.0.01
else
    tar zxf $ARCHIVE_PATH/RemoteViewBox2-web-1.0.0.01.tar.gz -C /opt/rsupport/rvbox/web/1.0.0.01
    gzip -d -f .information2-web.gz
    cp .information2-web /opt/rsupport/rvbox/web/1.0.0.01
    gzip .information2-web
fi

echo "3. make sysdir"
make_sysdir

echo "4. make conf files"
make_conf

echo "5. Stop cron schedule"
crontab -r
WEB_WATCH_PID=`ps -ef | grep -v grep | grep "for i in 1 2 3; do /opt/rsupport/rvbox/web/latest/watchdog.sh web && sleep 15; done" | awk '{print $1}'`
if [ -z "$WEB_WATCH_PID" ]
then
   echo "web watchdog is not running"
else
   echo "kill web watchdog"
   kill -9 $WEB_WATCH_PID
fi

echo "6. Kill web proess"
kill_process lighttpd
pkill -9 fcgi

echo "7. Check install files"
for CHECK_FILE in $CHECK_FILE_LIST
do
    if [ -e $INSTALL_DIR/$CHECK_FILE ] && [ -s $INSTALL_DIR/$CHECK_FILE ]; then 
        echo "ok...$CHECK_FILE"
     else
         echo "err...$CHECK_FILE"
         UPDATE_ROLLBACK="true"
    fi
done;

if [ "false" == "$UPDATE_ROLLBACK" ]
then
    echo "    7.1. Install Success. "
    if [ -d /opt/rsupport/rvbox/web/1n3OVRAW ]; then  # if pacakage version is same
        rm -rf /opt/rsupport/rvbox/web/1n3OVRAW
    fi

    # delete backup conf files.(lighttpd.conf, network.sh, ip_renewal.sh, app.sh)
    if [ -e /etc/rsupport/rvbox/web/lighttpd.conf1n3OVRAW ]; then 
       rm /etc/rsupport/rvbox/web/lighttpd.conf1n3OVRAW
    fi 
    if [ -e /etc/init.d/network.sh1n3OVRAW ]; then 
       rm /etc/init.d/network.sh1n3OVRAW
    fi 
    if [ -e /etc/init.d/ip_renewal.sh1n3OVRAW ]; then 
       rm /etc/init.d/ip_renewal.sh1n3OVRAW
    fi 
    if [ -e /etc/init.d/app.sh1n3OVRAW ]; then 
       rm /etc/init.d/app.sh1n3OVRAW
    fi 
    if [ -L /opt/rsupport/rvbox/web/latest ]; then
        CURRENT_VERSION_PATH=`readlink /opt/rsupport/rvbox/web/latest`
        rm /opt/rsupport/rvbox/web/latest

        if [ "$CURRENT_VERSION_PATH" == "/opt/rsupport/rvbox/web/1.0.0.01" ]; then   # if pacakage version is same
           echo "pacakage version is same"
        elif [ -d $CURRENT_VERSION_PATH ]; then  # if the package version is different, delete old version
           echo "delete $CURRENT_VERSION_PATH"
           rm -rf $CURRENT_VERSION_PATH
        fi
    fi
    echo "1.0.0.0101" > /opt/rsupport/rvbox/version
    ln -sf /opt/rsupport/rvbox/web/1.0.0.01 /opt/rsupport/rvbox/web/latest
else
    echo "    7.1. Install Fail.  rollback."
    rm -rf /opt/rsupport/rvbox/web/1.0.0.01
    if [ -d /opt/rsupport/rvbox/web/1n3OVRAW ]; then
        mv /opt/rsupport/rvbox/web/1n3OVRAW /opt/rsupport/rvbox/web/1.0.0.01
    fi
    # rollback conf files.(lighttpd.conf, network.sh, ip_renewal.sh, app.sh)
    if [ -e /etc/rsupport/rvbox/web/lighttpd.conf1n3OVRAW ]; then 
       mv /etc/rsupport/rvbox/web/lighttpd.conf1n3OVRAW /etc/rsupport/rvbox/web/lighttpd.conf
    fi 

    if [ -e /etc/init.d/ip_renewal.sh1n3OVRAW ]; then 
       mv /etc/init.d/ip_renewal.sh1n3OVRAW /etc/init.d/ip_renewal.sh
    fi 

    if [ -e /etc/init.d/network.sh1n3OVRAW ]; then 
       mv /etc/init.d/network.sh1n3OVRAW /etc/init.d/network.sh
    fi 

    if [ -e /etc/init.d/app.sh1n3OVRAW ]; then 
       mv /etc/init.d/app.sh1n3OVRAW /etc/init.d/app.sh
    fi 

fi

echo "8. Register cron schedule"
echo "* * * * * for i in 1 2 3; do /opt/rsupport/rvbox/agent/latest/watchdog.sh agent && sleep 15; done" > /var/spool/cron/crontabs/root
echo "* * * * * for i in 1 2 3; do /opt/rsupport/rvbox/web/latest/watchdog.sh web && sleep 15; done" >> /var/spool/cron/crontabs/root

rm /opt/rsupport/rvbox/web/latest/install-web.sh

echo "9. Synchronize Storage"
sync

echo "10. Start Watchdog"
/opt/rsupport/rvbox/web/latest/watchdog.sh web

